# Copyright (c) 2010-2020 Jacob Hammack.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NON INFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


module Risu
	module Templates
		class ExploitablitySummary < Risu::Base::TemplateBase
			include TemplateHelper

			#
			def initialize
				@template_info =
				{
					:name => "exploitablity_summary",
					:author => "hammackj",
					:version => "0.0.1",
					:renderer => "PDF",
					:description => "Generates a Exploitablity Summary Report"
				}
			end

			# Generates a report with 4 Tables of findings showing which exploit
			# framework has a exploit for the vulnerable finding.
			def render output
				report_classification

				report_title Report.title
				report_subtitle "Exploitablity Summary Report"
				report_author "This report was prepared by\n#{Report.author}"

				@output.text "\n\n\n"

				@output.text "Scan Date:", :style => :bold
				@output.text "#{Report.scan_date}"
				@output.text "\n"

				headers = ["Vulnerability", "Total", "Core", "Metasploit", "Canvas", "ExploitHub", "d2"]
				header_widths = {0 => 230, 1 => 38, 2 => 38, 3 => 64, 4 => 48, 5 => 62, 6 => 32}

				heading1 "Critical Findings"
				table headers, header_widths, Item.exploitablity_matrix(Item.critical_risks_unique_sorted)
				new_page

				heading1 "High Findings"
				table headers, header_widths, Item.exploitablity_matrix(Item.high_risks_unique_sorted)
				new_page

				heading1 "Medium Findings"
				table headers, header_widths, Item.exploitablity_matrix(Item.medium_risks_unique_sorted)
				new_page

				heading1 "Low Findings"
				table headers, header_widths, Item.exploitablity_matrix(Item.low_risks_unique_sorted)
				new_page

				@output.number_pages "<page> of <total>", :at => [output.bounds.right - 75, 0], :width => 150, :page_filter => :all
			end
		end
	end
end
